@@ -52,10 +52,10 @@ class CompressorTest(TestCase):
 
     def test_absolute_path(self):
         absolute_path = self.compressor.absolute_path('../../images/sprite.png',
-            'css/plugins/gallery.css')
+            'css/plugins/')
         self.assertEquals(absolute_path, 'images/sprite.png')
         absolute_path = self.compressor.absolute_path('/images/sprite.png',
-            'css/plugins/gallery.css')
+            'css/plugins/')
         self.assertEquals(absolute_path, '/images/sprite.png')
 
     def test_template_name(self):
